@@ -341,7 +341,8 @@ gnibbles_init (void)
 
   for (i = 0; i < properties->numworms; i++) {
     worms[i] = gnibbles_worm_new (i);
-    gnibbles_scoreboard_register (scoreboard, worms[i]);
+    gnibbles_scoreboard_register (scoreboard, worms[i], 
+	                 colorval_name (properties->wormprops[i]->color));
   }
 
   gnibbles_scoreboard_update (scoreboard);
@@ -452,6 +453,11 @@ gnibbles_move_worms ()
 
   dead = g_new (gint, properties->numworms);
 
+  for (i = 0; i < properties->ai; i++) {
+    gnibbles_worm_ai_move (worms[properties->human + i]);
+  }
+
+
   if (boni->missed > MAXMISSED)
     for (i = 0; i < properties->numworms; i++)
       if (worms[i]->score)
@@ -502,16 +508,14 @@ gnibbles_move_worms ()
     if (dead[i]) {
       if (properties->numworms > 1)
 	worms[i]->score *= .7;
-      if (ggz_network_mode) {
-	if (!gnibbles_worm_lose_life (worms[i])) {
-	  gnibbles_worm_set_start (worms[i],
-				   worms[i]->xstart,
-				   worms[i]->ystart, WORMDOWN);
+      if (!gnibbles_worm_lose_life (worms[i])) {
+        gnibbles_worm_reset(worms[i]);
+        gnibbles_worm_set_start (worms[i],
+				 worms[i]->xstart,
+				 worms[i]->ystart, WORMDOWN);
+	return (CONTINUE);
 	}
 
-      } else {
-	status |= gnibbles_worm_lose_life (worms[i]) << 1;
-      }
     }
 
   for (i = 0; i < properties->numworms; i++)
@@ -532,11 +536,11 @@ gnibbles_move_worms ()
     if (worms[i]->lives > 0)
       nlives += 1;
   }
-  if (ggz_network_mode && nlives == 1) {
+  if (nlives == 1) {
     return (VICTORY);
   }
 
-  if (status || ggz_network_mode)
+  if (status)
     return (CONTINUE);
 
   gnibbles_play_sound ("crash");
@@ -594,7 +598,7 @@ gnibbles_show_scores (GtkWidget * window, gint pos)
   gchar *message;
 
   if (!scoresdialog) {
-    scoresdialog = games_scores_dialog_new (highscores, _("Nibbles Scores"));
+    scoresdialog = games_scores_dialog_new (GTK_WINDOW (window), highscores, _("Nibbles Scores"));
     games_scores_dialog_set_category_description (GAMES_SCORES_DIALOG
 						  (scoresdialog),
 						  _("Speed:"));
